#
# spec file for package lowdown
#
# Copyright (c) 2024 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


%global soname liblowdown1
#%%global version_string VERSION_1_1_0

Name:           lowdown
Version:        1.3.0
Release:        1.1
Summary:        Simple markdown translator
License:        ISC
#URL:            https://kristaps.bsd.lv/lowdown
URL:            https://github.com/kristapsdz/lowdown
#Source:         %%{name}-%%{version_string}.tar.gz
Source:         %{name}-%{version}.tar.gz
BuildRequires:  fdupes

%description
lowdown is a Markdown translator producing HTML5, roff documents in the ms and
man formats, LaTeX, gemini, OpenDocument, and terminal output.
The open source C source code has no dependencies. The tools are documented in
lowdown(1) and lowdown-diff(1), the language in lowdown(5),
and the library interface in lowdown(3).

lowdown is a fork of hoedown, although the parser and front-ends have changed
significantly.

%package -n %{soname}
Summary:        Simple markdown translator

%description -n %{soname}
lowdown is a fork of hoedown, although the parser and front-ends have changed
significantly.

%package devel
Summary:        Simple markdown translator
Requires:       %{soname} = %{version}

%description devel
lowdown is a fork of hoedown, although the parser and front-ends have changed
significantly.

%prep
#%%autosetup -p1 -n %%{name}-%%{version_string}
%autosetup -p1 -n %{name}-%{version}

%build
export CFLAGS="%{optflags}"
./configure PREFIX=%{_prefix} MANDIR=%{_mandir} LIBDIR=%{_libdir}
%make_build

%install
%make_install
%make_install install_libs
rm %{buildroot}%{_libdir}/*.a
chmod a+rx %{buildroot}%{_libdir}/liblowdown.so*
%fdupes -s %{buildroot}

%ldconfig_scriptlets -n %{soname}

%files
%{_bindir}/*
%{_mandir}/man1/*
%{_mandir}/man5/*
%{_datadir}/%{name}/

%files -n %{soname}
%{_libdir}/liblowdown.so.*

%files devel
%{_mandir}/man3/*
%{_libdir}/liblowdown.so
%{_libdir}/pkgconfig/lowdown.pc
%{_includedir}/*.h

%changelog
* Sun Dec  1 2024 mrueckert@suse.de
- Update to version 1.3.0:
  * New coverage.
  * Get ready for versions.
  * Note experimental status.
  * Synchronise manpages.
  * Add default HTML template.
  * Case insensitive, allow arguments, meta().
  * Add HTML-escaping functions.
  * Settle on case insensitive for templates.
  * Add some manpage bits for ongoing progress.
  * Use "dot" notation instead of "::".
  * Template "body" special value.
  * Add looping and listing to template.
  * Make valgrind run test cases.
  * Clarify corner case behaviour of templates.
  * Further specify metadata key canonicalisation.
  * Initial template functionality.
* Fri Oct 25 2024 mrueckert@suse.de
- Update to version 1.2.0:
  * Restructure.
  * Update images.
  * Simplify language.
  * Update coverage.
  * Get ready for version.
  * Add --nroff-endnotes for -tms.
  * Linked footnotes now enabled.
  * Ignore footnotes in headers.
  * Proper printing of -tms footnotes.
  * Ongoing version notes.
  * Use lowdown_get_meta() for -tfodt.
  * Use lowdown_get_meta().
  * Use lowdown_add_meta() instead of repeating.
  * Move shared metadata node->buffer into utility.
  * Document newly-recognised metadata.
  * Add msheader and manheader metadata and fix.
  * Initialise value.
  * Fix -thtml special characters in metadata.
  * Add regression test.
  * Version notes.
  * Add "latex header" and clean up.
  * Initialise no-escape statement.
  * Allow arbitrary HTML header content from metadata.
  * Update coverage.
  * Keep running version notes.
  * --nroff-no-groff -> nroff-traditional
  * Use UR/UE and MT/ME for -man links.
  * Remove unused.
  * Support OSC8 hyperlinking in -tterm.
  * More regression tests.
  * Be explicit about disallowing nested links.
  * Tweak style.
* Wed Oct  2 2024 mrueckert@suse.de
- Update to version 1.1.2:
  * Bump version.
  * Exercise entities, remove dead function.
  * Exercise RCS convention conversions.
  * Add html regressions to bundle.
  * More regressions (coverage).
  * Document --html-titleblock and tweak.
  * Github link in coverage table.
  * Fix regress/standalone invocation and add HTML.
  * DOS regressions.
  * More pandoc metadata testing (coverage).
  * More rigorous metadata testing (coverage).
  * More regressions (test coverage).
  * Introduce test coverage.
  * Tweak.
* Wed Sep 25 2024 Marcus Rueckert <mrueckert@suse.de>
- Update to version 1.1.1:
  * Tweak website, bump version.
  * Silence compiler warning.
  * Document code fences.
  * Improve Mac OS X buggy SH handling.
  * Synchronise source/man for --term-all-metadata.
  * Add regressions for tighter utf8 handling.
  * Tweak previous.
  * Don't output a newline after `.SH`
  * Ignore `test-*.dSYM` directories for macOS configure
  * Fix `iscntrl` on macOS
- cleanup the _service file:
  - Given we only package taged releases change the version to use
    the PARENT_TAG only and provide a better pattern as a comment
    in case we ever need a snapshot
  - instead of hardcoding the match and rewrite string actually use
    a regexp
* Fri Jul 26 2024 Scott Bradnick <scott.bradnick@suse.com>
- Updating %%{version} as requested in
  https://build.opensuse.org/request/show/1189627
* Fri Jul  5 2024 Scott Bradnick <scott.bradnick@suse.com>
- Updating %%description as requested in
  https://build.opensuse.org/request/show/1175614
* Tue May 14 2024 Scott Bradnick <scott.bradnick@suse.com>
- Borrowed from OBS://home:darix:apps/lowdown as lowdown can be used to create
  btop man page
  * Adjusted to use _service file and pull from gh://kristapsdz/lowdown
* Tue May 14 2024 scott.bradnick@suse.com
- Update to version VERSION_1_1_0+git20231119.1200b9f:
  * Enable GitHub actions.
  * Have valgrind rule return.
  * Bring up to date with oconfigure.
  * More typo fixes
  * Last bits for version.
  * Fix forced multiline blockquotes in -tgemini.
  * In -tgemini, print newline after blockcode.
  * Get ready for 1.1.0.
  * Add --term-all-meta for compatibility.
* Sun Feb  4 2024 Marcus Rueckert <mrueckert@suse.de>
- initial package
